#ifndef SETTINGS_H
#define SETTINGS_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QCheckBox>
#include <QtGui/QGridLayout>
#include <QtGui/QGroupBox>
#include <QtGui/QHBoxLayout>
#include <QtGui/QLabel>
#include <QtGui/QLineEdit>
#include <QtGui/QPushButton>
#include <QtGui/QSpacerItem>
#include <QtGui/QVBoxLayout>
#include <QtGui/QWidget>

#include "Config.h"

class SettingsDialog : public QWidget
{
	Q_OBJECT
public:
    QGridLayout *gridLayout;
    QVBoxLayout *vboxLayout;
    QCheckBox *active;
    QGroupBox *groupBox;
    QHBoxLayout *hboxLayout;
    QGridLayout *gridLayout1;
    QLabel *label;
    QLineEdit *password;
    QLineEdit *login;
    QLabel *label_2;
    QHBoxLayout *hboxLayout1;
    QSpacerItem *spacerItem;
    QPushButton *ok;
    QPushButton *cancel;
    Config* configuration;

    SettingsDialog(Config* config) : QWidget(0, Qt::Tool | Qt::WindowStaysOnTopHint)
    {
    configuration = config;
    setObjectName(QString::fromUtf8("settings"));
    setWindowIcon(QIcon());
    gridLayout = new QGridLayout(this);
    gridLayout->setSpacing(6);
    gridLayout->setMargin(8);
    gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
    vboxLayout = new QVBoxLayout();
    vboxLayout->setSpacing(6);
    vboxLayout->setMargin(0);
    vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
    active = new QCheckBox(this);
    active->setObjectName(QString::fromUtf8("active"));
    active->setText(QApplication::translate("settings", "Plugin is active", 0, QApplication::UnicodeUTF8));
    active->setChecked(configuration->enabled);

    vboxLayout->addWidget(active);

    groupBox = new QGroupBox(this);
    groupBox->setObjectName(QString::fromUtf8("groupBox"));
    hboxLayout = new QHBoxLayout(groupBox);
    hboxLayout->setSpacing(6);
    hboxLayout->setMargin(8);
    hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
    gridLayout1 = new QGridLayout();
    gridLayout1->setSpacing(6);
    gridLayout1->setMargin(0);
    gridLayout1->setObjectName(QString::fromUtf8("gridLayout1"));
    label = new QLabel(groupBox);
    label->setObjectName(QString::fromUtf8("label"));

    gridLayout1->addWidget(label, 0, 0, 1, 1);

    login = new QLineEdit(groupBox);
    login->setObjectName(QString::fromUtf8("login"));
    login->setText(configuration->login);

    gridLayout1->addWidget(login, 0, 1, 1, 1);

    password = new QLineEdit(groupBox);
    password->setObjectName(QString::fromUtf8("password"));
    password->setEchoMode(QLineEdit::Password);
    password->setText(configuration->password);

    gridLayout1->addWidget(password, 1, 1, 1, 1);



    label_2 = new QLabel(groupBox);
    label_2->setObjectName(QString::fromUtf8("label_2"));

    gridLayout1->addWidget(label_2, 1, 0, 1, 1);


    hboxLayout->addLayout(gridLayout1);


    vboxLayout->addWidget(groupBox);

    hboxLayout1 = new QHBoxLayout();
    hboxLayout1->setSpacing(6);
    hboxLayout1->setMargin(0);
    hboxLayout1->setObjectName(QString::fromUtf8("hboxLayout1"));
    spacerItem = new QSpacerItem(131, 31, QSizePolicy::Expanding, QSizePolicy::Minimum);

    hboxLayout1->addItem(spacerItem);

    ok = new QPushButton(this);
    ok->setObjectName(QString::fromUtf8("ok"));

    hboxLayout1->addWidget(ok);

    cancel = new QPushButton(this);
    cancel->setObjectName(QString::fromUtf8("cancel"));

    hboxLayout1->addWidget(cancel);


    vboxLayout->addLayout(hboxLayout1);


    gridLayout->addLayout(vboxLayout, 0, 0, 1, 1);

    retranslateUi();
    QObject::connect(ok, SIGNAL(clicked()), this, SLOT(okSlot()));
    QObject::connect(cancel, SIGNAL(clicked()), this, SLOT(cancelSlot()));

    QMetaObject::connectSlotsByName(this);
    } // setupUi

    void retranslateUi()
    {
    setWindowTitle(QApplication::translate("settings", "WinampSpy settings", 0, QApplication::UnicodeUTF8));
    groupBox->setTitle(QApplication::translate("settings", "Account settings", 0, QApplication::UnicodeUTF8));
    label->setText(QApplication::translate("settings", "Login", 0, QApplication::UnicodeUTF8));
    label_2->setText(QApplication::translate("settings", "Password", 0, QApplication::UnicodeUTF8));
    ok->setText(QApplication::translate("settings", "OK", 0, QApplication::UnicodeUTF8));
    cancel->setText(QApplication::translate("settings", "Cancel", 0, QApplication::UnicodeUTF8));
    Q_UNUSED(this);
    } // retranslateUi
    
protected:
	void closeEvent ( QCloseEvent * e ) {
		cancelSlot();
	}  
 
public slots:
	void cancelSlot() {
		password->setText(configuration->password);
		login->setText(configuration->login);
		active->setChecked(configuration->enabled);
		hide();
	}
	
	void okSlot() {
		configuration->password = password->text();
		configuration->login = login->text();
		configuration->enabled = active->isChecked();
		hide();
	}
};

#endif // SETTINGS_H
